summaryrefslogtreecommitdiffstats
path: root/kmail/partNode.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/partNode.cpp')
-rw-r--r--kmail/partNode.cpp60
1 files changed, 30 insertions, 30 deletions
diff --git a/kmail/partNode.cpp b/kmail/partNode.cpp
index b75c54e42..96bb32c59 100644
--- a/kmail/partNode.cpp
+++ b/kmail/partNode.cpp
@@ -19,11 +19,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -50,7 +50,7 @@
===========================================================================
- N O T E : The partNode structure will most likely be tqreplaced by KMime.
+ N O T E : The partNode structure will most likely be replaced by KMime.
It's purpose: Speed optimization for KDE 3. (khz, 28.11.01)
===========================================================================
*/
@@ -209,7 +209,7 @@ void partNode::buildObjectTree( bool processSiblings )
&& curNode->dwPart()->Next() ) ) {
curNode = curNode->mRoot;
}
- // we might have to leave when all children have been processed
+ // we might have to leave when all tqchildren have been processed
if( this == curNode && !processSiblings )
return;
// store next node
@@ -236,8 +236,8 @@ TQCString partNode::subTypeString() const {
const partNode* partNode::topLevelParent() const {
const partNode *ret = this;
- while ( ret->parentNode() )
- ret = ret->parentNode();
+ while ( ret->tqparentNode() )
+ ret = ret->tqparentNode();
return ret;
}
@@ -259,10 +259,10 @@ int partNode::totalChildCount() const {
TQString partNode::contentTypeParameter( const char * name ) const {
if ( !mDwPart || !mDwPart->hasHeaders() )
- return TQString::null;
+ return TQString();
DwHeaders & headers = mDwPart->Headers();
if ( !headers.HasContentType() )
- return TQString::null;
+ return TQString();
DwString attr = name;
attr.ConvertToLowerCase();
for ( DwParameter * param = headers.ContentType().FirstParameter() ; param ; param = param->Next() ) {
@@ -272,14 +272,14 @@ TQString partNode::contentTypeParameter( const char * name ) const {
return TQString::tqfromLatin1( param->Value().data(), param->Value().size() );
// warning: misses rfc2231 handling!
}
- return TQString::null;
+ return TQString();
}
KMMsgEncryptionState partNode::overallEncryptionState() const
{
KMMsgEncryptionState myState = KMMsgEncryptionStateUnknown;
if( mEncryptionState == KMMsgNotEncrypted ) {
// NOTE: children are tested ONLY when parent is not encrypted
if( mChild )
myState = mChild->overallEncryptionState();
else
@@ -320,7 +320,7 @@ KMMsgSignatureState partNode::overallSignatureState() const
{
KMMsgSignatureState myState = KMMsgSignatureStateUnknown;
if( mSignatureState == KMMsgNotSigned ) {
// children are tested ONLY when parent is not signed
if( mChild )
myState = mChild->overallSignatureState();
else
@@ -358,9 +358,9 @@ KMMsgSignatureState partNode::overallSignatureState() const
TQCString partNode::path() const
{
- if ( !parentNode() )
+ if ( !tqparentNode() )
return ':';
- const partNode * p = parentNode();
+ const partNode * p = tqparentNode();
// count number of siblings with the same type as us:
int nth = 0;
@@ -463,7 +463,7 @@ partNode* partNode::findTypeNot( int type, int subType, bool deep, bool wide )
return 0;
}
-void partNode::fillMimePartTree( KMMimePartTreeItem* parentItem,
+void partNode::fillMimePartTree( KMMimePartTreeItem* tqparentItem,
KMMimePartTree* mimePartTree,
TQString labelDescr,
TQString labelCntType,
@@ -471,11 +471,11 @@ void partNode::fillMimePartTree( KMMimePartTreeItem* parentItem,
KIO::filesize_t size,
bool revertOrder )
{
- if( parentItem || mimePartTree ) {
+ if( tqparentItem || mimePartTree ) {
if( mNext )
- mNext->fillMimePartTree( parentItem, mimePartTree,
- TQString::null, TQString::null, TQString::null, 0,
+ mNext->fillMimePartTree( tqparentItem, mimePartTree,
+ TQString(), TQString(), TQString(), 0,
revertOrder );
TQString cntDesc, cntType, cntEnc;
@@ -518,8 +518,8 @@ void partNode::fillMimePartTree( KMMimePartTreeItem* parentItem,
// remove linebreak+whitespace from folded Content-Description
cntDesc.tqreplace( TQRegExp("\\n\\s*"), " " );
- if( parentItem )
- mMimePartTreeItem = new KMMimePartTreeItem( parentItem,
+ if( tqparentItem )
+ mMimePartTreeItem = new KMMimePartTreeItem( tqparentItem,
this,
cntDesc,
cntType,
@@ -536,7 +536,7 @@ void partNode::fillMimePartTree( KMMimePartTreeItem* parentItem,
mMimePartTreeItem->setOpen( true );
if( mChild )
mChild->fillMimePartTree( mMimePartTreeItem, 0,
- TQString::null, TQString::null, TQString::null, 0,
+ TQString(), TQString(), TQString(), 0,
revertOrder );
}
@@ -595,7 +595,7 @@ partNode * partNode::next( bool allowChildren ) const {
return c;
if ( partNode * s = nextSibling() )
return s;
- for ( partNode * p = parentNode() ; p ; p = p->parentNode() )
+ for ( partNode * p = tqparentNode() ; p ; p = p->tqparentNode() )
if ( partNode * s = p->nextSibling() )
return s;
return 0;
@@ -607,7 +607,7 @@ bool partNode::isFirstTextPart() const {
const partNode * root = this;
// go up until we reach the root node of a message (of the actual message or
// of an attached message)
- while ( const partNode * p = root->parentNode() ) {
+ while ( const partNode * p = root->tqparentNode() ) {
if ( p->type() == DwMime::kTypeMessage )
break;
else
@@ -652,11 +652,11 @@ bool partNode::isInEncapsulatedMessage() const
const partNode * const topLevel = topLevelParent();
const partNode *cur = this;
while ( cur && cur != topLevel ) {
- const bool parentIsMessage = cur->parentNode() &&
- cur->parentNode()->msgPart().typeStr().lower() == "message";
- if ( parentIsMessage && cur->parentNode() != topLevel )
+ const bool tqparentIsMessage = cur->tqparentNode() &&
+ cur->tqparentNode()->msgPart().typeStr().lower() == "message";
+ if ( tqparentIsMessage && cur->tqparentNode() != topLevel )
return true;
- cur = cur->parentNode();
+ cur = cur->tqparentNode();
}
return false;
}
@@ -693,7 +693,7 @@ KMail::Interface::BodyPartMemento * partNode::internalBodyPartMemento( const TQC
{
assert( !reader() );
- const std::map<TQCString,KMail::Interface::BodyPartMemento*>::const_iterator it = mBodyPartMementoMap.find( which.lower() );
+ const std::map<TQCString,KMail::Interface::BodyPartMemento*>::const_iterator it = mBodyPartMementoMap.tqfind( which.lower() );
return it != mBodyPartMementoMap.end() ? it->second : 0 ;
}
@@ -768,8 +768,8 @@ partNode::AttachmentDisplayInfo partNode::attachmentDisplayInfo() const
typeBlacklisted = typeBlacklisted || this == topLevelParent();
bool firstTextChildOfEncapsulatedMsg = msgPart().typeStr().lower() == "text" &&
msgPart().subtypeStr().lower() == "plain" &&
- parentNode() &&
- parentNode()->msgPart().typeStr().lower() == "message";
+ tqparentNode() &&
+ tqparentNode()->msgPart().typeStr().lower() == "message";
typeBlacklisted = typeBlacklisted || firstTextChildOfEncapsulatedMsg;
info.displayInHeader = !info.label.isEmpty() && !info.icon.isEmpty() && !typeBlacklisted;
return info;
@@ -272,14 +272,14 @@ TQString partNode::contentTypeParameter( const char * name ) const {
KMMsgEncryptionState myState = KMMsgEncryptionStateUnknown;
if( mEncryptionState == KMMsgNotEncrypted ) {
- // NOTE: children are tested ONLY when parent is not encrypted
+ // NOTE: tqchildren are tested ONLY when tqparent is not encrypted
if( mChild )
myState = mChild->overallEncryptionState();
@@ -320,7 +320,7 @@ KMMsgSignatureState partNode::overallSignatureState() const
KMMsgSignatureState myState = KMMsgSignatureStateUnknown;
if( mSignatureState == KMMsgNotSigned ) {
- // children are tested ONLY when parent is not signed
+ // tqchildren are tested ONLY when tqparent is not signed
if( mChild )
myState = mChild->overallSignatureState();